@@ -19,6 +19,7 @@
  ***************************************************************************/
 
 #include "klettres.h"
+#include <kwidgetsaddons_version.h>
 
 //Qt includes
 #include <QAction>
@@ -186,9 +187,21 @@ void KLettres::setupActions()
     connect(m_grownupAction, &KToggleAction::triggered, this, &KLettres::slotModeGrownup);
     m_grownupAction->setWhatsThis(i18n("The Grownup mode is the normal mode where you can see the menubar."));
 
+#if KWIDGETSADDONS_VERSION < QT_VERSION_CHECK(5, 78, 0)
     connect(m_levelAction, static_cast<void (KSelectAction::*)(int)>(&KSelectAction::triggered), this, &KLettres::slotChangeLevel);
+#else
+    connect(m_levelAction, &KSelectAction::indexTriggered, this, &KLettres::slotChangeLevel);
+#endif
+#if KWIDGETSADDONS_VERSION < QT_VERSION_CHECK(5, 78, 0)
     connect(m_languageAction, static_cast<void (KSelectAction::*)(int)>(&KSelectAction::triggered), this, &KLettres::slotChangeLanguage);
+#else
+    connect(m_languageAction, &KSelectAction::indexTriggered, this, &KLettres::slotChangeLanguage);
+#endif
+#if KWIDGETSADDONS_VERSION < QT_VERSION_CHECK(5, 78, 0)
     connect(m_themeAction, static_cast<void (KSelectAction::*)(int)>(&KSelectAction::triggered), this, &KLettres::slotChangeTheme);
+#else
+    connect(m_themeAction, &KSelectAction::indexTriggered, this, &KLettres::slotChangeTheme);
+#endif
 
     KStandardAction::preferences(this, SLOT(optionsPreferences()), actionCollection());
 
@@ -220,11 +233,11 @@ void KLettres::optionsPreferences()
     }
 
     KConfigDialog *dialog = new KConfigDialog(this, QStringLiteral("settings"), Prefs::self());
-    dialog->addPage(new fontsdlg(nullptr), i18n("Font Settings"), QStringLiteral("preferences-desktop-font"));
+    dialog->addPage(new fontsdlg(nullptr), i18n("Font"), QStringLiteral("preferences-desktop-font"), i18n("Font Settings"));
     //fontsdlg is the page name, mFont is the widget name, Font Settings is the page display string
     //fonts is the icon
     Timer *m_timer = new Timer();
-    dialog->addPage(m_timer, i18n("Timer"), QStringLiteral("chronometer"));
+    dialog->addPage(m_timer, i18n("Timer"), QStringLiteral("chronometer"), i18n("Timer Settings"));
     connect(dialog, &KConfigDialog::settingsChanged, this, &KLettres::slotUpdateSettings);
     dialog->setAttribute( Qt::WA_DeleteOnClose );
     // dialog->setHelp(QString(), "klettres");
@@ -403,7 +416,9 @@ void KLettres::loadLangToolBar()
         QFile openFileStream(myFile.fileName());
         openFileStream.open(QIODevice::ReadOnly);
         QTextStream readFileStr(&openFileStream);
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
         readFileStr.setCodec("UTF-8");
+#endif
         //allData contains all the words from the file
         allData = readFileStr.readAll().split(QLatin1Char('\n'));
         openFileStream.close();
